/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EditorComponent } from './editor.component';
import { EditorFormatComponent } from './tools/format/editor-format.component';
import { EditorFontSizeComponent } from './tools/fontsize/editor-fontsize.component';
import { EditorFontFamilyComponent } from './tools/fontfamily/editor-fontfamily.component';
import { EditorColorPickerComponent } from './tools/colorpicker/editor-colorpicker.component';
import { EditorInsertTableButtonComponent } from './tools/tables/editor-insert-table-button.component';
import { EditorAlignLeftButtonDirective } from './tools/alignment/editor-align-left-button.directive';
import { EditorAlignCenterButtonDirective } from './tools/alignment/editor-align-center-button.directive';
import { EditorAlignRightButtonDirective } from './tools/alignment/editor-align-right-button.directive';
import { EditorAlignJustifyButtonDirective } from './tools/alignment/editor-align-justify-button.directive';
import { EditorBlockquoteDirective } from './tools/blockquote/editor-blockquote-button.directive';
import { EditorRedoButtonDirective } from './tools/history/editor-redo-button.directive';
import { EditorUndoButtonDirective } from './tools/history/editor-undo-button.directive';
import { EditorInsertImageButtonDirective } from './tools/image/editor-insert-image-button.directive';
import { EditorIndentButtonDirective } from './tools/indentation/editor-indent-button.directive';
import { EditorOutdentButtonDirective } from './tools/indentation/editor-outdent-button.directive';
import { EditorCreateLinkButtonDirective } from './tools/link/editor-create-link-button.directive';
import { EditorUnlinkButtonDirective } from './tools/link/editor-unlink-button.directive';
import { EditorInsertOrderedListButtonDirective } from './tools/list/editor-insert-ordered-list-button.directive';
import { EditorInsertUnorderedListButtonDirective } from './tools/list/editor-insert-unordered-list-button.directive';
import { EditorViewSourceButtonDirective } from './tools/source/editor-view-source-button.directive';
import { EditorBoldButtonDirective } from './tools/typographical-emphasis/editor-bold-button.directive';
import { EditorItalicButtonDirective } from './tools/typographical-emphasis/editor-italic-button.directive';
import { EditorUnderlineButtonDirective } from './tools/typographical-emphasis/editor-underline-button.directive';
import { EditorStrikethroughButtonDirective } from './tools/typographical-emphasis/editor-strikethrough-button.directive';
import { EditorSubscriptButtonDirective } from './tools/typographical-emphasis/editor-subscript-button.directive';
import { EditorSuperscriptButtonDirective } from './tools/typographical-emphasis/editor-superscript-button.directive';
import { EditorInsertFileButtonDirective } from './tools/link/editor-insert-file-button.directive';
import { EditorForeColorDirective } from './tools/colorpicker/editor-fore-color.directive';
import { EditorBackColorDirective } from './tools/colorpicker/editor-back-color.directive';
import { EditorCleanFormattingButtonDirective } from './tools/editor-clean-formatting-button.directive';
import { EditorAddColumnBeforeButtonDirective } from './tools/tables/editor-add-column-before-button.directive';
import { EditorAddColumnAfterButtonDirective } from './tools/tables/editor-add-column-after-button.directive';
import { EditorAddRowBeforeButtonDirective } from './tools/tables/editor-add-row-before-button.directive';
import { EditorAddRowAfterButtonDirective } from './tools/tables/editor-add-row-after-button.directive';
import { EditorDeleteColumnButtonDirective } from './tools/tables/editor-delete-column-button.directive';
import { EditorDeleteRowButtonDirective } from './tools/tables/editor-delete-row-button.directive';
import { EditorDeleteTableButtonDirective } from './tools/tables/editor-delete-table-button.directive';
import { CustomMessagesComponent } from './localization/custom-messages.component';
import { EditorPrintDirective } from './tools/print/editor-print-button.directive';
import { EditorSelectAllButtonDirective } from './tools/select-all/select-all-button.directive';
import { EditorSplitCellButtonDirective } from './tools/tables/editor-split-cell-button.directive';
import { EditorMergeCellsButtonDirective } from './tools/tables/editor-merge-cells-button.directive';
/**
 * Utility array that contains all `Editor` related components and directives
 */
export const KENDO_EDITOR = [
    EditorComponent,
    EditorAlignLeftButtonDirective,
    EditorAlignCenterButtonDirective,
    EditorAlignRightButtonDirective,
    EditorAlignJustifyButtonDirective,
    EditorInsertFileButtonDirective,
    EditorRedoButtonDirective,
    EditorUndoButtonDirective,
    EditorInsertImageButtonDirective,
    EditorIndentButtonDirective,
    EditorOutdentButtonDirective,
    EditorCreateLinkButtonDirective,
    EditorUnlinkButtonDirective,
    EditorInsertOrderedListButtonDirective,
    EditorInsertUnorderedListButtonDirective,
    EditorViewSourceButtonDirective,
    EditorBoldButtonDirective,
    EditorItalicButtonDirective,
    EditorUnderlineButtonDirective,
    EditorStrikethroughButtonDirective,
    EditorSubscriptButtonDirective,
    EditorSuperscriptButtonDirective,
    EditorForeColorDirective,
    EditorBackColorDirective,
    EditorCleanFormattingButtonDirective,
    EditorAddColumnBeforeButtonDirective,
    EditorAddColumnAfterButtonDirective,
    EditorAddRowBeforeButtonDirective,
    EditorAddRowAfterButtonDirective,
    EditorDeleteColumnButtonDirective,
    EditorDeleteRowButtonDirective,
    EditorDeleteTableButtonDirective,
    CustomMessagesComponent,
    EditorPrintDirective,
    EditorSelectAllButtonDirective,
    EditorBlockquoteDirective,
    EditorFontSizeComponent,
    EditorFontFamilyComponent,
    EditorFormatComponent,
    EditorColorPickerComponent,
    EditorInsertTableButtonComponent,
    EditorMergeCellsButtonDirective,
    EditorSplitCellButtonDirective
];
