/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { DialogContainerService, DialogService, WindowContainerService, WindowService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { KENDO_TOOLBAR } from '@progress/kendo-angular-toolbar';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_EDITOR } from './directives';
import * as i0 from "@angular/core";
import * as i1 from "./editor.component";
import * as i2 from "./tools/alignment/editor-align-left-button.directive";
import * as i3 from "./tools/alignment/editor-align-center-button.directive";
import * as i4 from "./tools/alignment/editor-align-right-button.directive";
import * as i5 from "./tools/alignment/editor-align-justify-button.directive";
import * as i6 from "./tools/link/editor-insert-file-button.directive";
import * as i7 from "./tools/history/editor-redo-button.directive";
import * as i8 from "./tools/history/editor-undo-button.directive";
import * as i9 from "./tools/image/editor-insert-image-button.directive";
import * as i10 from "./tools/indentation/editor-indent-button.directive";
import * as i11 from "./tools/indentation/editor-outdent-button.directive";
import * as i12 from "./tools/link/editor-create-link-button.directive";
import * as i13 from "./tools/link/editor-unlink-button.directive";
import * as i14 from "./tools/list/editor-insert-ordered-list-button.directive";
import * as i15 from "./tools/list/editor-insert-unordered-list-button.directive";
import * as i16 from "./tools/source/editor-view-source-button.directive";
import * as i17 from "./tools/typographical-emphasis/editor-bold-button.directive";
import * as i18 from "./tools/typographical-emphasis/editor-italic-button.directive";
import * as i19 from "./tools/typographical-emphasis/editor-underline-button.directive";
import * as i20 from "./tools/typographical-emphasis/editor-strikethrough-button.directive";
import * as i21 from "./tools/typographical-emphasis/editor-subscript-button.directive";
import * as i22 from "./tools/typographical-emphasis/editor-superscript-button.directive";
import * as i23 from "./tools/colorpicker/editor-fore-color.directive";
import * as i24 from "./tools/colorpicker/editor-back-color.directive";
import * as i25 from "./tools/editor-clean-formatting-button.directive";
import * as i26 from "./tools/tables/editor-add-column-before-button.directive";
import * as i27 from "./tools/tables/editor-add-column-after-button.directive";
import * as i28 from "./tools/tables/editor-add-row-before-button.directive";
import * as i29 from "./tools/tables/editor-add-row-after-button.directive";
import * as i30 from "./tools/tables/editor-delete-column-button.directive";
import * as i31 from "./tools/tables/editor-delete-row-button.directive";
import * as i32 from "./tools/tables/editor-delete-table-button.directive";
import * as i33 from "./localization/custom-messages.component";
import * as i34 from "./tools/print/editor-print-button.directive";
import * as i35 from "./tools/select-all/select-all-button.directive";
import * as i36 from "./tools/blockquote/editor-blockquote-button.directive";
import * as i37 from "./tools/fontsize/editor-fontsize.component";
import * as i38 from "./tools/fontfamily/editor-fontfamily.component";
import * as i39 from "./tools/format/editor-format.component";
import * as i40 from "./tools/colorpicker/editor-colorpicker.component";
import * as i41 from "./tools/tables/editor-insert-table-button.component";
import * as i42 from "./tools/tables/editor-merge-cells-button.directive";
import * as i43 from "./tools/tables/editor-split-cell-button.directive";
import * as i44 from "@progress/kendo-angular-toolbar";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi']) definition for the Editor component.
 *
 * ```ts-no-run
 * import { NgModule } from '@angular/core';
 * import { EditorModule } from '@progress/kendo-angular-editor';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { AppComponent } from './app.component';
 *
 * _@NgModule({
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, EditorModule],
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * ```
 */
export class EditorModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: EditorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: EditorModule, imports: [i1.EditorComponent, i2.EditorAlignLeftButtonDirective, i3.EditorAlignCenterButtonDirective, i4.EditorAlignRightButtonDirective, i5.EditorAlignJustifyButtonDirective, i6.EditorInsertFileButtonDirective, i7.EditorRedoButtonDirective, i8.EditorUndoButtonDirective, i9.EditorInsertImageButtonDirective, i10.EditorIndentButtonDirective, i11.EditorOutdentButtonDirective, i12.EditorCreateLinkButtonDirective, i13.EditorUnlinkButtonDirective, i14.EditorInsertOrderedListButtonDirective, i15.EditorInsertUnorderedListButtonDirective, i16.EditorViewSourceButtonDirective, i17.EditorBoldButtonDirective, i18.EditorItalicButtonDirective, i19.EditorUnderlineButtonDirective, i20.EditorStrikethroughButtonDirective, i21.EditorSubscriptButtonDirective, i22.EditorSuperscriptButtonDirective, i23.EditorForeColorDirective, i24.EditorBackColorDirective, i25.EditorCleanFormattingButtonDirective, i26.EditorAddColumnBeforeButtonDirective, i27.EditorAddColumnAfterButtonDirective, i28.EditorAddRowBeforeButtonDirective, i29.EditorAddRowAfterButtonDirective, i30.EditorDeleteColumnButtonDirective, i31.EditorDeleteRowButtonDirective, i32.EditorDeleteTableButtonDirective, i33.CustomMessagesComponent, i34.EditorPrintDirective, i35.EditorSelectAllButtonDirective, i36.EditorBlockquoteDirective, i37.EditorFontSizeComponent, i38.EditorFontFamilyComponent, i39.EditorFormatComponent, i40.EditorColorPickerComponent, i41.EditorInsertTableButtonComponent, i42.EditorMergeCellsButtonDirective, i43.EditorSplitCellButtonDirective, i44.ToolBarComponent, i44.ToolbarCustomMessagesComponent, i44.ToolBarButtonComponent, i44.ToolBarButtonGroupComponent, i44.ToolBarDropDownButtonComponent, i44.ToolBarSeparatorComponent, i44.ToolBarSpacerComponent, i44.ToolBarSplitButtonComponent, i44.ToolBarToolComponent], exports: [i1.EditorComponent, i2.EditorAlignLeftButtonDirective, i3.EditorAlignCenterButtonDirective, i4.EditorAlignRightButtonDirective, i5.EditorAlignJustifyButtonDirective, i6.EditorInsertFileButtonDirective, i7.EditorRedoButtonDirective, i8.EditorUndoButtonDirective, i9.EditorInsertImageButtonDirective, i10.EditorIndentButtonDirective, i11.EditorOutdentButtonDirective, i12.EditorCreateLinkButtonDirective, i13.EditorUnlinkButtonDirective, i14.EditorInsertOrderedListButtonDirective, i15.EditorInsertUnorderedListButtonDirective, i16.EditorViewSourceButtonDirective, i17.EditorBoldButtonDirective, i18.EditorItalicButtonDirective, i19.EditorUnderlineButtonDirective, i20.EditorStrikethroughButtonDirective, i21.EditorSubscriptButtonDirective, i22.EditorSuperscriptButtonDirective, i23.EditorForeColorDirective, i24.EditorBackColorDirective, i25.EditorCleanFormattingButtonDirective, i26.EditorAddColumnBeforeButtonDirective, i27.EditorAddColumnAfterButtonDirective, i28.EditorAddRowBeforeButtonDirective, i29.EditorAddRowAfterButtonDirective, i30.EditorDeleteColumnButtonDirective, i31.EditorDeleteRowButtonDirective, i32.EditorDeleteTableButtonDirective, i33.CustomMessagesComponent, i34.EditorPrintDirective, i35.EditorSelectAllButtonDirective, i36.EditorBlockquoteDirective, i37.EditorFontSizeComponent, i38.EditorFontFamilyComponent, i39.EditorFormatComponent, i40.EditorColorPickerComponent, i41.EditorInsertTableButtonComponent, i42.EditorMergeCellsButtonDirective, i43.EditorSplitCellButtonDirective, i44.ToolBarComponent, i44.ToolbarCustomMessagesComponent, i44.ToolBarButtonComponent, i44.ToolBarButtonGroupComponent, i44.ToolBarDropDownButtonComponent, i44.ToolBarSeparatorComponent, i44.ToolBarSpacerComponent, i44.ToolBarSplitButtonComponent, i44.ToolBarToolComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: EditorModule, providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService], imports: [i1.EditorComponent, i37.EditorFontSizeComponent, i38.EditorFontFamilyComponent, i39.EditorFormatComponent, i40.EditorColorPickerComponent, i41.EditorInsertTableButtonComponent, i44.ToolBarComponent, i44.ToolbarCustomMessagesComponent, i44.ToolBarButtonComponent, i44.ToolBarButtonGroupComponent, i44.ToolBarDropDownButtonComponent, i44.ToolBarSeparatorComponent, i44.ToolBarSpacerComponent, i44.ToolBarSplitButtonComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: EditorModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_EDITOR, ...KENDO_TOOLBAR],
                    imports: [...KENDO_EDITOR, ...KENDO_TOOLBAR],
                    providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService]
                }]
        }] });
