/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Input } from '@angular/core';
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class MessagesDirective extends ComponentMessages {
    /* Section of Tools Messages */
    /**
     * The title of the tool that aligns text in the center.
     */
    alignCenter;
    /**
     * The title of the tool that justifies text both left and right.
     */
    alignJustify;
    /**
     * The title of the tool that aligns text on the left.
     */
    alignLeft;
    /**
     * The title of the tool that aligns text on the right.
     */
    alignRight;
    /**
     * The title of the tool that changes the text background color.
     */
    backColor;
    /**
     * The title of the tool that wraps an element in a blockquote.
     */
    blockquote;
    /**
     * The title of the tool that makes text bold.
     */
    bold;
    /**
     * The title of the Clean Formatting tool.
     */
    cleanFormatting;
    /**
     * The title of the tool that creates hyperlinks.
     */
    createLink;
    /**
     * The title of the tool that changes the text font.
     */
    fontFamily;
    /**
     * The title of the tool that changes the text size.
     */
    fontSize;
    /**
     * The title of the tool that changes the text color.
     */
    foreColor;
    /**
     * The title of the tool that lets users choose block formats.
     */
    format;
    /**
     * The title of the tool that indents the content.
     */
    indent;
    /**
     * The title of the tool that inserts links to files.
     */
    insertFile;
    /**
     * The title of the tool that inserts images.
     */
    insertImage;
    /**
     * The title of the tool that inserts an ordered list.
     */
    insertOrderedList;
    /**
     * The title of the tool that inserts an unordered list.
     */
    insertUnorderedList;
    /**
     * The title of the tool that makes text italicized.
     */
    italic;
    /**
     * The title of the tool that outdents the content.
     */
    outdent;
    /**
     * The title of the print tool.
     */
    print;
    /**
     * The title of the tool that redos the last action.
     */
    redo;
    /**
     * The title of the tool that selects all content.
     */
    selectAll;
    /**
     * The title of the tool that strikes through text.
     */
    strikethrough;
    /**
     * The title of the tool that makes text subscript.
     */
    subscript;
    /**
     * The title of the tool that makes text superscript.
     */
    superscript;
    /**
     * The title of the tool that underlines text.
     */
    underline;
    /**
     * The title of the tool that undos the last action.
     */
    undo;
    /**
     * The title of the tool that removes hyperlinks.
     */
    unlink;
    /**
     * The title of the tool that shows the editor value as HTML.
     */
    viewSource;
    /**
     * The title of the tool that inserts table.
     */
    insertTable;
    /**
    * The caption for the hint in the insert table tool.
    *
    * The message consists of several parts - the amount of rows, the amount of columns, an `x` separator, and a localizable string.
    * To allow for reordering its parts, the `insertTableHint` input accepts a string with placeholders for the selected rows, selected columns
    * and the separator. The `{rows}` and `{columns}` placeholders will be replaced internally with the respective actual values. The `{x}` placeholder
    * shows a separator only when rows and columns are selected.
    */
    insertTableHint;
    /**
     * The title of the tool that adds new column before currently selected column.
     */
    addColumnBefore;
    /**
     * The title of the tool that adds new column after currently selected column.
     */
    addColumnAfter;
    /**
     * The title of the tool that adds new row before currently selected row.
     */
    addRowBefore;
    /**
     * The title of the tool that adds new row after currently selected row.
     */
    addRowAfter;
    /**
     * The title of the tool that deletes a table column.
     */
    deleteColumn;
    /**
     * The title of the tool that deletes a table row.
     */
    deleteRow;
    /**
     * The title of the tool that deletes a table.
     */
    deleteTable;
    /**
     * The title of the tool that merges the currently selected cells.
     */
    mergeCells;
    /**
     * The title of the tool that splits the currently selected cell.
     */
    splitCell;
    /* End of Tools Messages Section */
    /* Section of Dialog Messages */
    /**
     * The label of the **Apply** button in all Editor dialogs.
     */
    dialogApply;
    /**
     * The label of the **Cancel** button in all editor dialogs.
     */
    dialogCancel;
    /**
     * The label of the **Insert** button in all editor dialogs.
     */
    dialogInsert;
    /**
     * The label of the **Update** button in all editor dialogs.
     */
    dialogUpdate;
    /**
     * The caption for the file text in the insertFile dialog.
     */
    fileText;
    /**
     * The caption for the file Title in the insertFile dialog.
     */
    fileTitle;
    /**
     * The caption for the file URL in the insertFile dialog.
     */
    fileWebAddress;
    /**
     * The caption for the image alternate text in the insertImage dialog.
     */
    imageAltText;
    /**
     * The caption for the image height in the insertImage dialog.
     */
    imageHeight;
    /**
     * The caption for the image URL in the insertImage dialog.
     */
    imageWebAddress;
    /**
     * The caption for the image width in the insertImage dialog.
     */
    imageWidth;
    /**
     * The caption for the checkbox for opening the link in a new window in the createLink dialog.
     */
    linkOpenInNewWindow;
    /**
     * The caption for the link text in the createLink dialog.
     */
    linkText;
    /**
     * The caption for the link title in the createLink dialog.
     */
    linkTitle;
    /**
     * The caption for the URL in the createLink dialog.
     */
    linkWebAddress;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MessagesDirective, selector: "[kendoEditorMessages]", inputs: { alignCenter: "alignCenter", alignJustify: "alignJustify", alignLeft: "alignLeft", alignRight: "alignRight", backColor: "backColor", blockquote: "blockquote", bold: "bold", cleanFormatting: "cleanFormatting", createLink: "createLink", fontFamily: "fontFamily", fontSize: "fontSize", foreColor: "foreColor", format: "format", indent: "indent", insertFile: "insertFile", insertImage: "insertImage", insertOrderedList: "insertOrderedList", insertUnorderedList: "insertUnorderedList", italic: "italic", outdent: "outdent", print: "print", redo: "redo", selectAll: "selectAll", strikethrough: "strikethrough", subscript: "subscript", superscript: "superscript", underline: "underline", undo: "undo", unlink: "unlink", viewSource: "viewSource", insertTable: "insertTable", insertTableHint: "insertTableHint", addColumnBefore: "addColumnBefore", addColumnAfter: "addColumnAfter", addRowBefore: "addRowBefore", addRowAfter: "addRowAfter", deleteColumn: "deleteColumn", deleteRow: "deleteRow", deleteTable: "deleteTable", mergeCells: "mergeCells", splitCell: "splitCell", dialogApply: "dialogApply", dialogCancel: "dialogCancel", dialogInsert: "dialogInsert", dialogUpdate: "dialogUpdate", fileText: "fileText", fileTitle: "fileTitle", fileWebAddress: "fileWebAddress", imageAltText: "imageAltText", imageHeight: "imageHeight", imageWebAddress: "imageWebAddress", imageWidth: "imageWidth", linkOpenInNewWindow: "linkOpenInNewWindow", linkText: "linkText", linkTitle: "linkTitle", linkWebAddress: "linkWebAddress" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoEditorMessages]'
                }]
        }], propDecorators: { alignCenter: [{
                type: Input
            }], alignJustify: [{
                type: Input
            }], alignLeft: [{
                type: Input
            }], alignRight: [{
                type: Input
            }], backColor: [{
                type: Input
            }], blockquote: [{
                type: Input
            }], bold: [{
                type: Input
            }], cleanFormatting: [{
                type: Input
            }], createLink: [{
                type: Input
            }], fontFamily: [{
                type: Input
            }], fontSize: [{
                type: Input
            }], foreColor: [{
                type: Input
            }], format: [{
                type: Input
            }], indent: [{
                type: Input
            }], insertFile: [{
                type: Input
            }], insertImage: [{
                type: Input
            }], insertOrderedList: [{
                type: Input
            }], insertUnorderedList: [{
                type: Input
            }], italic: [{
                type: Input
            }], outdent: [{
                type: Input
            }], print: [{
                type: Input
            }], redo: [{
                type: Input
            }], selectAll: [{
                type: Input
            }], strikethrough: [{
                type: Input
            }], subscript: [{
                type: Input
            }], superscript: [{
                type: Input
            }], underline: [{
                type: Input
            }], undo: [{
                type: Input
            }], unlink: [{
                type: Input
            }], viewSource: [{
                type: Input
            }], insertTable: [{
                type: Input
            }], insertTableHint: [{
                type: Input
            }], addColumnBefore: [{
                type: Input
            }], addColumnAfter: [{
                type: Input
            }], addRowBefore: [{
                type: Input
            }], addRowAfter: [{
                type: Input
            }], deleteColumn: [{
                type: Input
            }], deleteRow: [{
                type: Input
            }], deleteTable: [{
                type: Input
            }], mergeCells: [{
                type: Input
            }], splitCell: [{
                type: Input
            }], dialogApply: [{
                type: Input
            }], dialogCancel: [{
                type: Input
            }], dialogInsert: [{
                type: Input
            }], dialogUpdate: [{
                type: Input
            }], fileText: [{
                type: Input
            }], fileTitle: [{
                type: Input
            }], fileWebAddress: [{
                type: Input
            }], imageAltText: [{
                type: Input
            }], imageHeight: [{
                type: Input
            }], imageWebAddress: [{
                type: Input
            }], imageWidth: [{
                type: Input
            }], linkOpenInNewWindow: [{
                type: Input
            }], linkText: [{
                type: Input
            }], linkTitle: [{
                type: Input
            }], linkWebAddress: [{
                type: Input
            }] } });
