/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class MessagesDirective extends ComponentMessages {
    /**
     * The title of the tool that aligns text in the center.
     */
    alignCenter: string;
    /**
     * The title of the tool that justifies text both left and right.
     */
    alignJustify: string;
    /**
     * The title of the tool that aligns text on the left.
     */
    alignLeft: string;
    /**
     * The title of the tool that aligns text on the right.
     */
    alignRight: string;
    /**
     * The title of the tool that changes the text background color.
     */
    backColor: string;
    /**
     * The title of the tool that wraps an element in a blockquote.
     */
    blockquote: string;
    /**
     * The title of the tool that makes text bold.
     */
    bold: string;
    /**
     * The title of the Clean Formatting tool.
     */
    cleanFormatting: string;
    /**
     * The title of the tool that creates hyperlinks.
     */
    createLink: string;
    /**
     * The title of the tool that changes the text font.
     */
    fontFamily: string;
    /**
     * The title of the tool that changes the text size.
     */
    fontSize: string;
    /**
     * The title of the tool that changes the text color.
     */
    foreColor: string;
    /**
     * The title of the tool that lets users choose block formats.
     */
    format: string;
    /**
     * The title of the tool that indents the content.
     */
    indent: string;
    /**
     * The title of the tool that inserts links to files.
     */
    insertFile: string;
    /**
     * The title of the tool that inserts images.
     */
    insertImage: string;
    /**
     * The title of the tool that inserts an ordered list.
     */
    insertOrderedList: string;
    /**
     * The title of the tool that inserts an unordered list.
     */
    insertUnorderedList: string;
    /**
     * The title of the tool that makes text italicized.
     */
    italic: string;
    /**
     * The title of the tool that outdents the content.
     */
    outdent: string;
    /**
     * The title of the print tool.
     */
    print: string;
    /**
     * The title of the tool that redos the last action.
     */
    redo: string;
    /**
     * The title of the tool that selects all content.
     */
    selectAll: string;
    /**
     * The title of the tool that strikes through text.
     */
    strikethrough: string;
    /**
     * The title of the tool that makes text subscript.
     */
    subscript: string;
    /**
     * The title of the tool that makes text superscript.
     */
    superscript: string;
    /**
     * The title of the tool that underlines text.
     */
    underline: string;
    /**
     * The title of the tool that undos the last action.
     */
    undo: string;
    /**
     * The title of the tool that removes hyperlinks.
     */
    unlink: string;
    /**
     * The title of the tool that shows the editor value as HTML.
     */
    viewSource: string;
    /**
     * The title of the tool that inserts table.
     */
    insertTable: string;
    /**
    * The caption for the hint in the insert table tool.
    *
    * The message consists of several parts - the amount of rows, the amount of columns, an `x` separator, and a localizable string.
    * To allow for reordering its parts, the `insertTableHint` input accepts a string with placeholders for the selected rows, selected columns
    * and the separator. The `{rows}` and `{columns}` placeholders will be replaced internally with the respective actual values. The `{x}` placeholder
    * shows a separator only when rows and columns are selected.
    */
    insertTableHint: string;
    /**
     * The title of the tool that adds new column before currently selected column.
     */
    addColumnBefore: string;
    /**
     * The title of the tool that adds new column after currently selected column.
     */
    addColumnAfter: string;
    /**
     * The title of the tool that adds new row before currently selected row.
     */
    addRowBefore: string;
    /**
     * The title of the tool that adds new row after currently selected row.
     */
    addRowAfter: string;
    /**
     * The title of the tool that deletes a table column.
     */
    deleteColumn: string;
    /**
     * The title of the tool that deletes a table row.
     */
    deleteRow: string;
    /**
     * The title of the tool that deletes a table.
     */
    deleteTable: string;
    /**
     * The title of the tool that merges the currently selected cells.
     */
    mergeCells: string;
    /**
     * The title of the tool that splits the currently selected cell.
     */
    splitCell: string;
    /**
     * The label of the **Apply** button in all Editor dialogs.
     */
    dialogApply: string;
    /**
     * The label of the **Cancel** button in all editor dialogs.
     */
    dialogCancel: string;
    /**
     * The label of the **Insert** button in all editor dialogs.
     */
    dialogInsert: string;
    /**
     * The label of the **Update** button in all editor dialogs.
     */
    dialogUpdate: string;
    /**
     * The caption for the file text in the insertFile dialog.
     */
    fileText: string;
    /**
     * The caption for the file Title in the insertFile dialog.
     */
    fileTitle: string;
    /**
     * The caption for the file URL in the insertFile dialog.
     */
    fileWebAddress: string;
    /**
     * The caption for the image alternate text in the insertImage dialog.
     */
    imageAltText: string;
    /**
     * The caption for the image height in the insertImage dialog.
     */
    imageHeight: string;
    /**
     * The caption for the image URL in the insertImage dialog.
     */
    imageWebAddress: string;
    /**
     * The caption for the image width in the insertImage dialog.
     */
    imageWidth: string;
    /**
     * The caption for the checkbox for opening the link in a new window in the createLink dialog.
     */
    linkOpenInNewWindow: string;
    /**
     * The caption for the link text in the createLink dialog.
     */
    linkText: string;
    /**
     * The caption for the link title in the createLink dialog.
     */
    linkTitle: string;
    /**
     * The caption for the URL in the createLink dialog.
     */
    linkWebAddress: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<MessagesDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MessagesDirective, "[kendoEditorMessages]", never, { "alignCenter": { "alias": "alignCenter"; "required": false; }; "alignJustify": { "alias": "alignJustify"; "required": false; }; "alignLeft": { "alias": "alignLeft"; "required": false; }; "alignRight": { "alias": "alignRight"; "required": false; }; "backColor": { "alias": "backColor"; "required": false; }; "blockquote": { "alias": "blockquote"; "required": false; }; "bold": { "alias": "bold"; "required": false; }; "cleanFormatting": { "alias": "cleanFormatting"; "required": false; }; "createLink": { "alias": "createLink"; "required": false; }; "fontFamily": { "alias": "fontFamily"; "required": false; }; "fontSize": { "alias": "fontSize"; "required": false; }; "foreColor": { "alias": "foreColor"; "required": false; }; "format": { "alias": "format"; "required": false; }; "indent": { "alias": "indent"; "required": false; }; "insertFile": { "alias": "insertFile"; "required": false; }; "insertImage": { "alias": "insertImage"; "required": false; }; "insertOrderedList": { "alias": "insertOrderedList"; "required": false; }; "insertUnorderedList": { "alias": "insertUnorderedList"; "required": false; }; "italic": { "alias": "italic"; "required": false; }; "outdent": { "alias": "outdent"; "required": false; }; "print": { "alias": "print"; "required": false; }; "redo": { "alias": "redo"; "required": false; }; "selectAll": { "alias": "selectAll"; "required": false; }; "strikethrough": { "alias": "strikethrough"; "required": false; }; "subscript": { "alias": "subscript"; "required": false; }; "superscript": { "alias": "superscript"; "required": false; }; "underline": { "alias": "underline"; "required": false; }; "undo": { "alias": "undo"; "required": false; }; "unlink": { "alias": "unlink"; "required": false; }; "viewSource": { "alias": "viewSource"; "required": false; }; "insertTable": { "alias": "insertTable"; "required": false; }; "insertTableHint": { "alias": "insertTableHint"; "required": false; }; "addColumnBefore": { "alias": "addColumnBefore"; "required": false; }; "addColumnAfter": { "alias": "addColumnAfter"; "required": false; }; "addRowBefore": { "alias": "addRowBefore"; "required": false; }; "addRowAfter": { "alias": "addRowAfter"; "required": false; }; "deleteColumn": { "alias": "deleteColumn"; "required": false; }; "deleteRow": { "alias": "deleteRow"; "required": false; }; "deleteTable": { "alias": "deleteTable"; "required": false; }; "mergeCells": { "alias": "mergeCells"; "required": false; }; "splitCell": { "alias": "splitCell"; "required": false; }; "dialogApply": { "alias": "dialogApply"; "required": false; }; "dialogCancel": { "alias": "dialogCancel"; "required": false; }; "dialogInsert": { "alias": "dialogInsert"; "required": false; }; "dialogUpdate": { "alias": "dialogUpdate"; "required": false; }; "fileText": { "alias": "fileText"; "required": false; }; "fileTitle": { "alias": "fileTitle"; "required": false; }; "fileWebAddress": { "alias": "fileWebAddress"; "required": false; }; "imageAltText": { "alias": "imageAltText"; "required": false; }; "imageHeight": { "alias": "imageHeight"; "required": false; }; "imageWebAddress": { "alias": "imageWebAddress"; "required": false; }; "imageWidth": { "alias": "imageWidth"; "required": false; }; "linkOpenInNewWindow": { "alias": "linkOpenInNewWindow"; "required": false; }; "linkText": { "alias": "linkText"; "required": false; }; "linkTitle": { "alias": "linkTitle"; "required": false; }; "linkWebAddress": { "alias": "linkWebAddress"; "required": false; }; }, {}, never, never, false, never>;
}
