/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { EditorCommandButton } from '../shared/editor-command-button';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { ProviderService } from '../../common/provider.service';
import { EditorToolsService } from '../tools.service';
import * as i0 from "@angular/core";
/**
 * A directive which configures an existing `ToolBarButtonComponent` as an Editor **AlignJustify** tool
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools)).
 * The directive will predefine the SVG icon and `click` event handlers of the button.
 * In addition, the directive updates the `selected` state of the button according to the cursor position in the editing area.
 *
 * @example
 * ```html
 * <kendo-toolbar-button kendoEditorAlignJustifyButton></kendo-toolbar-button>
 * ```
 */
export declare class EditorAlignJustifyButtonDirective extends EditorCommandButton {
    constructor(button: ToolBarButtonComponent, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService);
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorAlignJustifyButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EditorAlignJustifyButtonDirective, "kendo-toolbar-button[kendoEditorAlignJustifyButton]", never, {}, {}, never, never, true, never>;
}
