/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, EventEmitter, Renderer2 } from '@angular/core';
import { ToolBarToolComponent } from '@progress/kendo-angular-toolbar';
import { DialogService } from '@progress/kendo-angular-dialog';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { FontFamilyItem } from '../../common/font-family-item.interface';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { FontFamilyDropDownListComponent } from './editor-fontfamily-dropdownlist.component';
import { ProviderService } from '../../common/provider.service';
import { EditorToolsService } from '../tools.service';
import * as i0 from "@angular/core";
/**
 * A component which configures an existing `DropDownListComponent` as an Editor tool
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools)).
 * The component associates a `kendo-toolbar-dropdownlist` with an Editor command that changes the font family of a content block and
 * automatically defines the options of the drop-down list and sets its values ([see example]({% slug toolbartools_editor %}#toc-dropdownlists)).
 *
 * @example
 * ```ts-no-run
 * <kendo-toolbar-dropdownlist kendoEditorFontFamily></kendo-toolbar-dropdownlist>
 * ```
 */
export declare class EditorFontFamilyComponent extends ToolBarToolComponent {
    private dialogService;
    private localization;
    private toolsService;
    private renderer;
    value: string;
    disabled: boolean;
    tabindex: number;
    /**
     * Overrides the default font list.
     */
    set data(fonts: FontFamilyItem[]);
    get data(): FontFamilyItem[];
    /**
     * Fires when the user updates the value of the drop-down list.
     */
    valueChange: EventEmitter<FontFamilyItem>;
    element: ElementRef;
    fontFamilyDropDownList: FontFamilyDropDownListComponent;
    fontFamilyButton: ElementRef;
    /**
     * @hidden
     */
    defaultItem: FontFamilyItem;
    /**
     * @hidden
     */
    itemDisabled: (itemArgs: {
        dataItem: any;
        index: number;
    }) => boolean;
    fontFamilySVGIcon: SVGIcon;
    private subs;
    private editor;
    private _data;
    constructor(dialogService: DialogService, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService, renderer: Renderer2);
    ngOnInit(): void;
    /**
     * @hidden
     */
    onValueChange(ev: string): void;
    ngOnDestroy(): void;
    get outerWidth(): number;
    get title(): string;
    /**
     * @hidden
     */
    openDialog(): void;
    /**
     * @hidden
     */
    canFocus(): boolean;
    /**
     * @hidden
     */
    focus(): void;
    /**
     * @hidden
     */
    handleKey(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorFontFamilyComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EditorFontFamilyComponent, "kendo-toolbar-dropdownlist[kendoEditorFontFamily]", never, { "data": { "alias": "data"; "required": false; }; }, { "valueChange": "valueChange"; }, never, never, true, never>;
}
