/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, EventEmitter, Renderer2 } from '@angular/core';
import { ToolBarToolComponent } from '@progress/kendo-angular-toolbar';
import { ItemDisabledFn } from '@progress/kendo-angular-dropdowns';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { DialogService } from '@progress/kendo-angular-dialog';
import { FontSizeItem } from '../../common/font-size-item.interface';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { FontSizeDropDownListComponent } from './editor-fontsize-dropdownlist.component';
import { ProviderService } from '../../common/provider.service';
import { EditorToolsService } from '../tools.service';
import * as i0 from "@angular/core";
/**
 * A component which configures an existing `DropDownListComponent` as an Editor tool
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools)).
 * The component associates a `kendo-dropdownlist` with an Editor command that changes the font size of a content block and
 * automatically defines the options of the drop-down list and sets its values ([see example]({% slug toolbartools_editor %}#toc-dropdownlists)).
 *
 * @example
 * ```ts-no-run
 * <kendo-toolbar-dropdownlist kendoEditorFontSize></kendo-toolbar-dropdownlist>
 * ```
 */
export declare class EditorFontSizeComponent extends ToolBarToolComponent {
    private dialogService;
    private localization;
    private toolsService;
    private renderer;
    value: string;
    disabled: boolean;
    tabindex: number;
    /**
     * Overrides the default font size list.
     * Numeric values are treated as pixels.
     */
    set data(sizes: FontSizeItem[]);
    get data(): FontSizeItem[];
    /**
     * Fires when the user updates the value of the drop-down list.
     */
    valueChange: EventEmitter<FontSizeItem>;
    element: ElementRef;
    fontSizeDropDownList: FontSizeDropDownListComponent;
    fontSizeButton: ElementRef;
    /**
     * @hidden
     */
    defaultItem: FontSizeItem;
    fontSizeSVGIcon: SVGIcon;
    /**
     * @hidden
     */
    itemDisabled: ItemDisabledFn;
    private subs;
    private editor;
    private _data;
    constructor(dialogService: DialogService, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService, renderer: Renderer2);
    ngOnInit(): void;
    /**
     * @hidden
     */
    onValueChange(ev: string): void;
    ngOnDestroy(): void;
    get outerWidth(): number;
    get title(): string;
    /**
     * @hidden
     */
    openDialog(): void;
    /**
     * @hidden
     */
    canFocus(): boolean;
    /**
     * @hidden
     */
    focus(): void;
    /**
     * @hidden
     */
    handleKey(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorFontSizeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EditorFontSizeComponent, "kendo-toolbar-dropdownlist[kendoEditorFontSize]", never, { "data": { "alias": "data"; "required": false; }; }, { "valueChange": "valueChange"; }, never, never, true, never>;
}
