/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef, Renderer2 } from '@angular/core';
import { ToolBarToolComponent } from '@progress/kendo-angular-toolbar';
import { ItemDisabledFn } from '@progress/kendo-angular-dropdowns';
import { DialogService } from '@progress/kendo-angular-dialog';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { FormatItem } from '../../common/format-item.interface';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { FormatDropDownListComponent } from './editor-format-dropdownlist.component';
import { ProviderService } from '../../common/provider.service';
import { EditorToolsService } from '../tools.service';
import * as i0 from "@angular/core";
/**
 * A component which configures an existing `DropDownListComponent` as an Editor tool
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools)).
 * The component associates a `kendo-dropdownlist` with an Editor command that changes the format of a content block and
 * automatically defines the options of the drop-down list and sets its values ([see example]({% slug toolbartools_editor %}#toc-dropdownlists)).
 *
 * @example
 * ```ts-no-run
 * <kendo-toolbar-dropdownlist kendoEditorFormat></kendo-toolbar-dropdownlist>
 * ```
 */
export declare class EditorFormatComponent extends ToolBarToolComponent {
    private dialogService;
    private localization;
    private toolsService;
    private renderer;
    value: string;
    defaultItem: FormatItem;
    itemDisabled: ItemDisabledFn;
    disabled: boolean;
    tabindex: number;
    /**
     * Overrides the default format items list.
     */
    set data(formatItems: FormatItem[]);
    get data(): FormatItem[];
    /**
     * Fires when the user updates the value of the drop-down list.
     */
    valueChange: EventEmitter<FormatItem>;
    formatDropDownList: FormatDropDownListComponent;
    formatButton: ElementRef;
    private subs;
    private _data;
    applyFormatSVGIcon: SVGIcon;
    private editor;
    constructor(dialogService: DialogService, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService, renderer: Renderer2);
    ngOnInit(): void;
    /**
     * @hidden
     */
    onValueChange(ev: string): void;
    ngOnDestroy(): void;
    get outerWidth(): number;
    get title(): string;
    /**
     * @hidden
     */
    openDialog(): void;
    /**
     * @hidden
     */
    canFocus(): boolean;
    /**
     * @hidden
     */
    focus(): void;
    /**
     * @hidden
     */
    handleKey(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorFormatComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EditorFormatComponent, "kendo-toolbar-dropdownlist[kendoEditorFormat]", never, { "data": { "alias": "data"; "required": false; }; }, { "valueChange": "valueChange"; }, never, never, true, never>;
}
