/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef, ElementRef, OnDestroy, Renderer2 } from '@angular/core';
import { ToolBarToolComponent } from '@progress/kendo-angular-toolbar';
import { PopupRef, PopupService } from '@progress/kendo-angular-popup';
import { DialogService } from '@progress/kendo-angular-dialog';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { ProviderService } from '../../common/provider.service';
import { TableData } from '../../common/table-data.interface';
import * as i0 from "@angular/core";
/**
 * A toolbar component which allows the user to create and insert a table in the Editor's content.
 *
 * @example
 * ```html
 * <kendo-editor-insert-table-button></kendo-editor-insert-table-button>
 * ```
 */
export declare class EditorInsertTableButtonComponent extends ToolBarToolComponent implements OnDestroy {
    private localization;
    private popupService;
    private dialogService;
    private renderer;
    element: ElementRef;
    overflowElement: ElementRef;
    popupGridTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    popupRef: PopupRef;
    /**
     * @hidden
     */
    disabled: boolean;
    addTableSVGIcon: SVGIcon;
    private open;
    private buttonBlurred;
    private cellClicked;
    private subs;
    private editor;
    constructor(localization: EditorLocalizationService, popupService: PopupService, dialogService: DialogService, providerService: ProviderService, renderer: Renderer2);
    ngOnDestroy(): void;
    get outerWidth(): number;
    get title(): string;
    /**
     * @hidden
     */
    toggle(open?: boolean): void;
    /**
     * @hidden
     */
    openDialog(): void;
    /**
     * @hidden
     */
    onBlur(): void;
    /**
     * @hidden
     */
    onCellClick(args: TableData): void;
    /**
     * @hidden
     */
    canFocus(): boolean;
    /**
     * @hidden
     */
    focus(): void;
    /**
     * @hidden
     */
    handleKey(ev: any): boolean;
    /**
     * @hidden
     */
    onTableWizardClick(): void;
    private createPopup;
    private destroyPopup;
    private getButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorInsertTableButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EditorInsertTableButtonComponent, "kendo-editor-insert-table-button", never, {}, {}, never, never, true, never>;
}
